ipsec whack --impair send_nonzero_reserved_id
ipsec auto --up westnet-eastnet-ipv4-psk-ikev2
echo done
